@@ -25,8 +25,12 @@ class AdbExt(object):
 
     def dump(self):
         for i in range(5):
-            out = self.util.adb('exec-out uiautomator dump /dev/tty').replace('UI hierchary dumped to: /dev/tty', '')
-            if '<hierarchy' in out:
+            out = self.util.adb('exec-out uiautomator dump /dev/tty', encoding='')
+
+            start = out.find(b'<?xml')
+            end = out.find(b'</hierarchy>') + len(b'</hierarchy>')
+            if start >= 0 and end > 0:  # 检查是否有xml文档
+                out = out[start: end]  # 去掉xml前后的内容
                 return out
         raise NameError('dump xml fail!')
 
